# frozen_string_literal: true

require 'dependency_updater/handlers/gitlab_handler'
require 'dependency_updater/handlers/gem_handler'
require 'dependency_updater/handlers/ruby_handler'

module DependencyUpdater
  class Updater
    def initialize
      @gitlab = GitlabHandler.new
      @gem = GemHandler.new(@gitlab)
      @ruby = RubyHandler.new(@gitlab)
      @updates = false
    end

    def git_init
      @gitlab.new_branch
    end

    def update_ruby
      @ruby.find_version_data
      @updates = true if @ruby.update_project_files
    end

    def update_gems_and_cap_deploy
      @updates = true if @gem.update_gems
      @gem.update_capistrano_deploy
    end

    def wrap_up
      @updates ? @gitlab.create_mr : @gitlab.backout
    end
  end
end
